marktools.Annotation
====================

.. inheritance-diagram:: abjad.tools.marktools.Annotation.Annotation.Annotation
   :private-bases:

.. autoclass:: abjad.tools.marktools.Annotation.Annotation.Annotation

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.marktools.Annotation.Annotation.Annotation.start_component

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.marktools.Annotation.Annotation.Annotation.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.marktools.Annotation.Annotation.Annotation.name

.. autoattribute:: abjad.tools.marktools.Annotation.Annotation.Annotation.value

Methods
-------

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.attach

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.detach

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

Special Methods
---------------

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__call__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__delattr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__eq__

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__ne__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.marktools.Annotation.Annotation.Annotation.__repr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`
